#!/Users/Moris/Script/Stonky/.env/bin/python3

from datetime import datetime
from json import load
from time import sleep

from stonky.strategies.loss_rebuy import LossReBuy
from stonky.strategies.mean_trend import MeanTrend
from stonky.utils import k


def bot_instance(bot):
    strategies = {"mean-trend": MeanTrend, "loss-rebuy": LossReBuy}
    return strategies.get(bot.get("strategy"))(*list(bot.values())[1:])


def get_crypto_data(bots):
    since = datetime.timestamp(datetime.now()) - 86400  # 1 day
    search = set((pair, bot.interval) for bot in bots for pair in bot.pairs)
    print(search)
    return {
        f"{pair}-{interval}": k.query_public(
            "OHLC", data={"pair": pair, "interval": interval, "since": since}
        )
        .get("result")
        .get(pair)
        for pair, interval in search
    }


def main():
    bots = [bot_instance(bot) for bot in load(open("bots.json")).get("bots")]
    while True:
        CRYPTO_DATA = get_crypto_data(bots)
        for bot in bots:
            print(f"---- BOT [{bot.name}] ----")
            bot.iteration(CRYPTO_DATA)
        sleep(10)


if __name__ == "__main__":
    main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="stonky-bot",
    version="0.0.3",
    author="Moris Doratiotto",
    author_email="moris.doratiotto@gmail.com",
    description="A python crypto trading bot for Kraken",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mortafix/Stonky",
    packages=setuptools.find_packages(),
    install_requires=[
        "krakenex",
    ],
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
    ],
    python_requires=">=3.8",
    keywords=["bot", "trading", "crypto", "kraken"],
    package_data={
        "stonky": [
            "utils.py",
            "strategies/mean_trend.py",
            "strategies/loss_rebuy.py",
        ]
    },
    entry_points={"console_scripts": ["stonky=stonky.stonky:main"]},
)



from os import makedirs, path
from re import sub

from stornky.utils import save_data


class LossReBuy:
    def __init__(
        self, name, currency, budget, pairs, single_buy, max_open, threshold, rebuy
    ):
        self.name = sub(r"\s+", "_", name)
        self.interval = 5
        self.main_balance = currency
        self.pairs = pairs
        self.single_buy = single_buy
        self.max_open = max_open
        self.threshold = threshold
        self.rebuy = rebuy
        data_basepath = path.join("data", self.name)
        if not path.exists(data_basepath):
            makedirs(data_basepath)
        save_data(self.name, {self.main_balance: budget}, "balance")

    def iteration(self, main_crypto_data):
        ...
